endpoint_instructions

Function endpoint_instructions 

fn endpoint_instructions(
    endpoint_type: McpEndpointType,
    query_tool_enabled: bool,
) -> Option<String>
Instructions returned in the initialize response for each endpoint type. These guide the AI agent on how to use the server correctly.