endpoint_instructions

Function endpoint_instructions 

fn endpoint_instructions(endpoint_type: McpEndpointType) -> Option<String>
Instructions returned in the initialize response for each endpoint type. These guide the AI agent on how to use the server correctly.